==> monodevelop_5.5.0.227.orig.tar.bz2: monodevelop-5.5/src/addins/MonoDevelop.PackageManagement/MonoDevelop.PackageManagement.NodeBuilders/PackageReferenceNodeBuilder.cs <==
﻿//
// PackageReferenceNodeBuilder.cs
//
// Author:
//       Matt Ward <matt.ward@xamarin.com>
//
// Copyright (c) 2014 Xamarin Inc. (http://xamarin.com)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using Gdk;
using MonoDevelop.Core;
using MonoDevelop.Ide.Gui;
using MonoDevelop.Ide.Gui.Components;
using MonoDevelop.PackageManagement.Commands;

namespace MonoDevelop.PackageManagement.NodeBuilders
{
	public class PackageReferenceNodeBuilder : TypeNodeBuilder
	{
		public override Type NodeDataType {
			get { return typeof(PackageReferenceNode); }
		}

		public override string GetNodeName (ITreeNavigator thisNode, object dataObject)
		{
			var packageReferenceNode = (PackageReferenceNode)dataObject;
			return packageReferenceNode.Name;
		}

		public override string ContextMenuAddinPath {
			get { return "/MonoDevelop/PackageManagement/ContextMenu/ProjectPad/PackageReference"; }
		}

		public override Type CommandHandlerType {
			get { return typeof(PackageReferenceNodeCommandHandler); }
		}

		public override void BuildNode (ITreeBuilder treeBuilder, object dataObject, NodeInfo nodeInfo)
		{
			var packageReferenceNode = (PackageReferenceNode)dataObject;
			nodeInfo.Label = packageReferenceNode.GetLabel ();
			nodeInfo.Icon = Context.GetIcon (packageReferenceNode.GetIconId ());
		}
	}
}

==> monodevelop_5.10.0.871.orig.tar.bz2: monodevelop-5.10/src/addins/MonoDevelop.PackageManagement/MonoDevelop.PackageManagement.NodeBuilders/PackageReferenceNodeBuilder.cs <==
﻿//
// PackageReferenceNodeBuilder.cs
//
// Author:
//       Matt Ward <matt.ward@xamarin.com>
//
// Copyright (c) 2014 Xamarin Inc. (http://xamarin.com)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using Gdk;
using MonoDevelop.Core;
using MonoDevelop.Ide.Gui;
using MonoDevelop.Ide.Gui.Components;
using MonoDevelop.PackageManagement.Commands;

namespace MonoDevelop.PackageManagement.NodeBuilders
{
	public class PackageReferenceNodeBuilder : TypeNodeBuilder
	{
		public override Type NodeDataType {
			get { return typeof(PackageReferenceNode); }
		}

		public override string GetNodeName (ITreeNavigator thisNode, object dataObject)
		{
			var packageReferenceNode = (PackageReferenceNode)dataObject;
			return packageReferenceNode.Name;
		}

		public override string ContextMenuAddinPath {
			get { return "/MonoDevelop/PackageManagement/ContextMenu/ProjectPad/PackageReference"; }
		}

		public override Type CommandHandlerType {
			get { return typeof(PackageReferenceNodeCommandHandler); }
		}

		public override void BuildNode (ITreeBuilder treeBuilder, object dataObject, NodeInfo nodeInfo)
		{
			var packageReferenceNode = (PackageReferenceNode)dataObject;
			nodeInfo.Label = packageReferenceNode.GetLabel ();
			nodeInfo.Icon = Context.GetIcon (packageReferenceNode.GetIconId ());
			nodeInfo.StatusSeverity = packageReferenceNode.GetStatusSeverity ();
			nodeInfo.StatusMessage = packageReferenceNode.GetStatusMessage ();
			nodeInfo.DisabledStyle = packageReferenceNode.IsDisabled ();
		}
	}
}
